From 613029631fa89c50998b9374161d79efdfbee6b3 Mon Sep 17 00:00:00 2001
From: Sven Buijssen <sven.buijssen@tu-dortmund.de>
Date: Tue, 14 Sep 2010 12:28:48 +0200
Subject: [PATCH 3/3] ENH: Provide a method to set axis of symmetry.

---
 Graphics/vtkSuperquadricSource.h |   12 +++++++++---
 1 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/Graphics/vtkSuperquadricSource.h b/Graphics/vtkSuperquadricSource.h
index 19bc964..7ee8317 100644
--- a/Graphics/vtkSuperquadricSource.h
+++ b/Graphics/vtkSuperquadricSource.h
@@ -15,9 +15,10 @@
 // .NAME vtkSuperquadricSource - create a polygonal superquadric centered 
 // at the origin
 // .SECTION Description
 // vtkSuperquadricSource creates a superquadric (represented by polygons) 
 // of specified
 // size centered at the origin. The resolution (polygonal discretization)
 // in both the latitude (phi) and longitude (theta) directions can be
 // specified. Roundness parameters (PhiRoundness and ThetaRoundness) control
 // the shape of the superquadric.  The Toroidal boolean controls whether
@@ -110,6 +111,11 @@ public:
   vtkGetMacro(Size,double);
 
   // Description:
+  // Set/Get axis of symmetry for superquadric (x axis: 0, y axis: 1, z axis: 2). Initial value is 2.
+  vtkSetMacro(AxisOfSymmetry,int);
+  vtkGetMacro(AxisOfSymmetry,int);
+
+  // Description:
   // Set/Get whether or not the superquadric is toroidal (1) or ellipsoidal (0).
   // Initial value is 0.
   vtkBooleanMacro(Toroidal,int);
@@ -15,9 +15,10 @@
 // at the origin
 // .SECTION Description
-// vtkSuperquadricSource creates a superquadric (represented by polygons) 
-// of specified
-// size centered at the origin. The resolution (polygonal discretization)
+// vtkSuperquadricSource creates a superquadric (represented by polygons) of
+// specified size centered at the origin. The alignment of the axis of the
+// superquadric along one of the global axes can be specified. The resolution
+// (polygonal discretization)
 // in both the latitude (phi) and longitude (theta) directions can be
 // specified. Roundness parameters (PhiRoundness and ThetaRoundness) control
-- 
1.7.2.2

